@@ -51,16 +51,17 @@ use ReadonlyX;
 use charnames qw(:full);
 
 # package constants
-Readonly our $BOTO_PATH_OFFSET    => 3;
-Readonly our $SHAPE_FILE_TEMPLATE => '%sAmazon/API/Botocore/Shape/%s/';
+Readonly::Scalar our $BOTO_PATH_OFFSET => 3;
+Readonly::Scalar our $SHAPE_FILE_TEMPLATE =>
+  '%sAmazon/API/Botocore/Shape/%s/';
 
-Readonly our $REQUEST_CLASS_TEMPLATE =>
+Readonly::Scalar our $REQUEST_CLASS_TEMPLATE =>
   q{Amazon::API::Botocore::Shape::%s::%sRequest};
 
 use Amazon::API::Constants qw( :all );
 use Amazon::API::Botocore::Pod qw( pod );
 
-our $VERSION = '2.0.2'; ## no critic (RequireInterpolationOfMetachars)
+our $VERSION = '2.0.3'; ## no critic (RequireInterpolationOfMetachars)
 
 our %BOTO_SERVICES;
 
@@ -1192,7 +1193,7 @@ our @API_METHODS = qw(
 @actions@
 );
 
-our $VERSION = '2.0.2';
+our $VERSION = '2.0.3';
 
 sub new {
   my ( $class, @options ) = @_;
